Function libpd_sys::libpd_add_double
source · [−]pub unsafe extern "C" fn libpd_add_double(x: f64)Expand description
add a double to the current message in progress note: only full-precision when compiled with PD_FLOATSIZE=64
pub unsafe extern "C" fn libpd_add_double(x: f64)add a double to the current message in progress note: only full-precision when compiled with PD_FLOATSIZE=64