pub unsafe extern "C" fn libpd_add_to_search_path(path: *const c_char)
add a path to the libpd search paths relative paths are relative to the current working directory unlike desktop pd, no search paths are set by default (ie. extra)