pub unsafe extern "C" fn libpd_bind(
    recv: *const c_char
) -> *mut c_void
subscribe to messages sent to a source receiver ex: libpd_bind(“foo”) adds a “virtual” [r foo] which forwards messages to the libpd message hooks returns an opaque receiver pointer or NULL on failure