Function libpd_sys::libpd_clear_search_path
source · [−]pub unsafe extern "C" fn libpd_clear_search_path()Expand description
clear the libpd search path for abstractions and externals note: this is called by libpd_init()
pub unsafe extern "C" fn libpd_clear_search_path()clear the libpd search path for abstractions and externals note: this is called by libpd_init()