pub unsafe extern "C" fn libpd_message(
    recv: *const c_char,
    msg: *const c_char,
    argc: c_int,
    argv: *mut t_atom
) -> c_int
send a atom array of a given length as a typed message to a destination receiver, returns 0 on success or -1 if receiver name is non-existent ex: send [; pd dsp 1( on the next tick with: t_atom v[1]; libpd_set_float(v, 1); libpd_message(“pd”, “dsp”, 1, v);