Function libpd_sys::libpd_num_instances
source · [−]pub unsafe extern "C" fn libpd_num_instances() -> c_intExpand description
get the number of pd instances returns number or 1 when libpd is not compiled with PDINSTANCE
pub unsafe extern "C" fn libpd_num_instances() -> c_intget the number of pd instances returns number or 1 when libpd is not compiled with PDINSTANCE