Function libpd_sys::libpd_process_raw_short
source · [−]pub unsafe extern "C" fn libpd_process_raw_short(
inBuffer: *const c_short,
outBuffer: *mut c_short
) -> c_intExpand description
process non-interleaved short samples from inBuffer -> libpd -> outBuffer copies buffer contents to/from libpd without striping buffer sizes are based on a single tick and # of channels where: size = libpd_blocksize() * (in/out)channels float samples are converted to short by multiplying by 32767 and casting, so any values received from pd patches beyond -1 to 1 will result in garbage note: for efficiency, does not clip input returns 0 on success