pub unsafe extern "C" fn libpd_read_array(
    dest: *mut f32,
    name: *const c_char,
    offset: c_int,
    n: c_int
) -> c_int
read n values from named src array and write into dest starting at an offset note: performs no bounds checking on dest returns 0 on success or a negative error code if the array is non-existent or offset + n exceeds range of array