Function libpd_sys::libpd_set_doublehook
source · [−]pub unsafe extern "C" fn libpd_set_doublehook(
hook: t_libpd_doublehook
)Expand description
set the double receiver hook, NULL by default note: avoid calling this while DSP is running note: you can either have a double receiver hook, or a float receiver hook (see above), but not both. calling this, will automatically unset the float receiver hook note: only full-precision when compiled with PD_FLOATSIZE=64