pub unsafe extern "C" fn libpd_set_queued_floathook(
    hook: t_libpd_floathook
)
set the queued float receiver hook, NULL by default note: avoid calling this while DSP is running note: you can either have a queued float receiver hook, or a queued double receiver hook (see below), but not both. calling this, will automatically unset the queued double receiver hook