pub unsafe extern "C" fn libpd_start_message(maxlen: c_int) -> c_int
start composition of a new list or typed message of up to max element length messages can be of a smaller length as max length is only an upper bound note: no cleanup is required for unfinished messages returns 0 on success or nonzero if the length is too large