pub unsafe extern "C" fn libpd_write_array(
    name: *const c_char,
    offset: c_int,
    src: *const f32,
    n: c_int
) -> c_int
read n values from src and write into named dest array starting at an offset note: performs no bounds checking on src returns 0 on success or a negative error code if the array is non-existent or offset + n exceeds range of array