Function libpd_sys::libpd_write_array_double
source · [−]pub unsafe extern "C" fn libpd_write_array_double(
dest: *const c_char,
offset: c_int,
src: *const f64,
n: c_int
) -> c_intExpand description
read n values from src and write into named dest array starting at an offset note: performs no bounds checking on src note: only full-precision when compiled with PD_FLOATSIZE=64 returns 0 on success or a negative error code if the array is non-existent or offset + n exceeds range of array double-precision variant of libpd_write_array()