Function libpd_sys::rb_available_to_read
source · [−]pub unsafe extern "C" fn rb_available_to_read(
buffer: *mut ring_buffer
) -> c_intExpand description
get the number of bytes that can currently be read this is safe to called from any thread