Function libpd_sys::rb_available_to_write
source · [−]pub unsafe extern "C" fn rb_available_to_write(
buffer: *mut ring_buffer
) -> c_intExpand description
get the number of bytes that can currently be written this is safe to call from any thread