Function libpd_sys::rb_clear_buffer
source · [−]pub unsafe extern "C" fn rb_clear_buffer(buffer: *mut ring_buffer)Expand description
clears the contents of the ring buffer this is safe to call from any thread
pub unsafe extern "C" fn rb_clear_buffer(buffer: *mut ring_buffer)clears the contents of the ring buffer this is safe to call from any thread