pub unsafe extern "C" fn rb_read_from_buffer(
    buffer: *mut ring_buffer,
    dest: *mut c_char,
    len: c_int
) -> c_int
read given number of bytes from the ring buffer to dest (if the ring buffer has enough data) note: call this from a single reader thread only returns 0 on success