Type Definition libpd_sys::t_libpd_noteonhook
source · [−]pub type t_libpd_noteonhook = Option<unsafe extern "C" fn(channel: c_int, pitch: c_int, velocity: c_int)>;Expand description
MIDI note on receive hook signature channel is 0-indexed, pitch is 0-127, and value is 0-127 channels encode MIDI ports via: libpd_channel = pd_channel + 16 * pd_port note: there is no note off message, note on w/ velocity = 0 is used instead note: out of range values from pd are clamped