Function libpd_sys::libpd_add_to_search_path
source · [−]Expand description
add a path to the libpd search paths relative paths are relative to the current working directory unlike desktop pd, no search paths are set by default (ie. extra)