Function libpd_sys::libpd_init
source · [−]pub unsafe extern "C" fn libpd_init() -> c_intExpand description
initialize libpd; it is safe to call this more than once returns 0 on success or -1 if libpd was already initialized note: sets SIGFPE handler to keep bad pd patches from crashing due to divide by 0, set any custom handling after calling this function