pub unsafe extern "C" fn libpd_process_short(
    ticks: c_int,
    inBuffer: *const c_short,
    outBuffer: *mut c_short
) -> c_int
process interleaved short samples from inBuffer -> libpd -> outBuffer buffer sizes are based on # of ticks and channels where: size = ticks * libpd_blocksize() * (in/out)channels float samples are converted to short by multiplying by 32767 and casting, so any values received from pd patches beyond -1 to 1 will result in garbage note: for efficiency, does not clip input returns 0 on success