Function libpd_sys::libpd_queued_init
source · [−]pub unsafe extern "C" fn libpd_queued_init() -> c_intExpand description
initialize libpd and the queued ringbuffers, use in place of libpd_init() this is safe to call more than once returns 0 on success, -1 if libpd was already initialized, or -2 if ring buffer allocation failed