Function libpd_sys::libpd_set_instance
source · [−]pub unsafe extern "C" fn libpd_set_instance(p: *mut _pdinstance)Expand description
set the current pd instance subsequent libpd calls will affect this instance only does nothing when libpd is not compiled with PDINSTANCE