Function libpd_sys::libpd_set_queued_doublehook
source · [−]pub unsafe extern "C" fn libpd_set_queued_doublehook(
hook: t_libpd_doublehook
)Expand description
set the queued double receiver hook, NULL by default note: avoid calling this while DSP is running note: you can either have a queued double receiver hook, or a queued float receiver hook (see above), but not both. calling this, will automatically unset the queued float receiver hook