Function libpd_sys::rb_write_to_buffer
source · [−]pub unsafe extern "C" fn rb_write_to_buffer(
buffer: *mut ring_buffer,
n: c_int,
...
) -> c_intExpand description
write bytes from n sources to the ring buffer (if the ring buffer has enough space), varargs are pairs of type (const char*, int) giving a pointer to a buffer and the number of bytes to be copied note: call this from a single writer thread only returns 0 on success