Function libpd_sys::rb_write_value_to_buffer
source · [−]pub unsafe extern "C" fn rb_write_value_to_buffer(
buffer: *mut ring_buffer,
value: c_int,
n: c_int
) -> c_intExpand description
writes single byte value n times to the ring buffer (if the ring buffer has enough space) note: call this from a single writer thread only returns 0 on success